@@ -16,7 +16,7 @@ summary(RegModel.1)
 # "Models" -> "Predict using active model" -> "Input data and predict"
 # In age column input 35 and 40 and then close the editor.
 # Rcmdr reply with the following command in source pane (R Script)
-.data <- edit(Chile[0,])
+.data <- edit(data.frame(age = numeric(0)))
 .data
 predict(RegModel.1, .data)
 remove(.data)
